# ggLeapAnalyticsTools
A python package for helping users to generate and interact with data from ggLeap esports venue management software created chiefly for work done for the University of Warwick's Esports Centre.
